
# THIS FILE IS GENERATED FROM wofrysrw SETUP.PY
short_version = '1.0.23'
version = '1.0.23'
full_version = '1.0.23.dev0+4a0f3b3'
git_revision = '4a0f3b3ac531a2cdc6562d17cd1d836855645406'
release = False

if not release:
    version = full_version
    short_version += ".dev"
